@@ -6,9 +6,11 @@ import mutagen
 
 from .file import EartagFile
 
+
 class EartagFileMutagenCommon(EartagFile):
     """Base class for Mutagen-based backends."""
-    __gtype_name__ = 'EartagFileMutagenCommon'
+
+    __gtype_name__ = "EartagFileMutagenCommon"
 
     def __init__(self, path):
         super().__init__(path)
@@ -28,6 +30,13 @@ class EartagFileMutagenCommon(EartagFile):
         super().on_remove()
         self.mg_file = None
 
+    def delete_all_raw(self):
+        self.delete_all()
+        if not self.mg_file.tags:
+            return
+        for tag in dict(self.mg_file.tags).keys():
+            del self.mg_file.tags[tag]
+
     # Main properties
 
     @GObject.Property(type=int, flags=GObject.ParamFlags.READABLE)
