@@ -5,6 +5,7 @@ from gi.repository import GObject
 import base64
 import magic
 import mimetypes
+import io
 from PIL import Image
 
 from mutagen.flac import FLAC, Picture, error as FLACError
@@ -36,6 +37,7 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
     )  # fmt: skip
 
     _replaces = {
+        "totaltracknumber": "tracktotal",
         "releasedate": "date",
         # There"s also ENCODED-BY, but confusingly it represents... the person doing the encoding?
         "encodedby": "encoder",
@@ -130,23 +132,23 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
             self.mg_file.clear_pictures()
             for _pic in pic_list:
                 self.mg_file.add_picture(_pic)
-        else:
-            pic_list = list(self.mg_file.get("metadata_block_picture", []))
-            for b64_data in pic_list.copy():
-                try:
-                    data = base64.b64decode(b64_data)
-                except (TypeError, ValueError):
-                    continue
 
-                try:
-                    cover_picture = Picture(data)
-                except FLACError:
-                    continue
+        pic_list = list(self.mg_file.get("metadata_block_picture", []))
+        for b64_data in pic_list.copy():
+            try:
+                data = base64.b64decode(b64_data)
+            except (TypeError, ValueError):
+                continue
 
-                if cover_picture.type in pictypes:
-                    pic_list.remove(b64_data)
+            try:
+                cover_picture = Picture(data)
+            except FLACError:
+                continue
 
-            self.mg_file["metadata_block_picture"] = pic_list
+            if cover_picture.type in pictypes:
+                pic_list.remove(b64_data)
+
+        self.mg_file["metadata_block_picture"] = pic_list
 
         if not clear_only:
             self._cleanup_cover(cover_type)
@@ -169,8 +171,21 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
         else:
             raise ValueError
 
-        with open(value, "rb") as cover_file:
-            data = cover_file.read()
+        # Allowed types are JPEG or PNG. For other types, convert to PNG first.
+        mime = magic.from_file(value, mime=True)
+        if mime == "image/jpg":
+            mime = "image/jpeg"
+
+        if mime in ("image/jpeg", "image/png"):
+            with open(value, "rb") as cover_file:
+                data = cover_file.read()
+        else:
+            # Convert to PNG
+            with Image.open(value) as img:
+                out = io.BytesIO()
+                img.save(out, format="PNG")
+                data = out.getvalue()
+            mime = "image/png"
 
         # shamelessly stolen from
         # https://stackoverflow.com/questions/1996577/how-can-i-get-the-depth-of-a-jpg-file
@@ -191,27 +206,27 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
         picture = Picture()
         picture.data = data
         picture.type = pictype
-        picture.mime = magic.from_file(value, mime=True)
-        img = Image.open(value)
-        picture.width = img.width
-        picture.height = img.height
-        picture.depth = mode_to_bpp[img.mode]
+        picture.mime = mime
+        with Image.open(value) as img:
+            picture.width = img.width
+            picture.height = img.height
+            picture.depth = mode_to_bpp[img.mode]
 
         # Remove all conflicting pictures
         self.delete_cover(cover_type, clear_only=True)
 
         if isinstance(self.mg_file, FLAC):
             self.mg_file.add_picture(picture)
+
+        picture_data = picture.write()
+        encoded_data = base64.b64encode(picture_data)
+        vcomment_value = encoded_data.decode("ascii")
+        if "metadata_block_picture" in self.mg_file:
+            self.mg_file["metadata_block_picture"] = [vcomment_value] + self.mg_file[
+                "metadata_block_picture"
+            ]
         else:
-            picture_data = picture.write()
-            encoded_data = base64.b64encode(picture_data)
-            vcomment_value = encoded_data.decode("ascii")
-            if "metadata_block_picture" in self.mg_file:
-                self.mg_file["metadata_block_picture"] = [
-                    vcomment_value
-                ] + self.mg_file["metadata_block_picture"]
-            else:
-                self.mg_file["metadata_block_picture"] = [vcomment_value]
+            self.mg_file["metadata_block_picture"] = [vcomment_value]
 
         self.mark_as_modified(prop)
 
@@ -351,20 +366,19 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
 
     @tracknumber.setter
     def tracknumber(self, value):
-        if self.totaltracknumber:
-            self.set_tag(
-                "tracknumber",
-                "{n}/{t}".format(n=str(value), t=str(self.totaltracknumber)),
-            )
+        if value:
+            self.set_tag("tracknumber", str(value))
         else:
-            if value:
-                self.set_tag("tracknumber", str(value))
-            elif self.has_tag("tracknumber"):
-                self.delete_tag("tracknumber")
+            self.delete_tag("tracknumber")
         self.mark_as_modified("tracknumber")
 
     @GObject.Property(type=int)
     def totaltracknumber(self):
+        totalnum_raw = self.get_tag("totaltracknumber")
+        if totalnum_raw:
+            return int(totalnum_raw)
+
+        # Fall back to parsing track number with "/" (older Ear Tag versions)
         tracknum_raw = self.get_tag("tracknumber")
         if not tracknum_raw:
             return None
@@ -374,15 +388,19 @@ class EartagFileMutagenVorbis(EartagFileMutagenCommon):
 
     @totaltracknumber.setter
     def totaltracknumber(self, value):
-        if self.tracknumber:
-            self.set_tag(
-                "tracknumber", "{n}/{t}".format(n=str(self.tracknumber), t=str(value))
-            )
-        else:
-            if value:
-                self.set_tag("tracknumber", "0/{t}".format(t=str(value)))
-            elif self.has_tag("tracknumber"):
+        # Fix up track numbers with "/"
+        if "/" in (self.get_tag("tracknumber") or ""):
+            if self.tracknumber:
+                self.set_tag("tracknumber", str(self.tracknumber))
+            else:
                 self.delete_tag("tracknumber")
+            self.mark_as_modified("tracknumber")
+
+        if value:
+            self.set_tag("totaltracknumber", str(value))
+        else:
+            self.delete_tag("totaltracknumber")
+
         self.mark_as_modified("totaltracknumber")
 
     @GObject.Property(type=int)
