@@ -301,7 +301,7 @@ class EartagAlbumCoverButton(Adw.Bin):
 
         self.cover_image.on_cover_change()
 
-        remove_msg = gettext.ngettext(
+        remove_msg = ngettext(
             "Removed cover from file", "Removed covers from {n} files", len(self.files)
         ).format(n=len(self.files))
         toast = Adw.Toast.new(remove_msg)
@@ -440,6 +440,7 @@ class EartagMoreTagsGroup(Gtk.Box):
         self._last_loaded_filetypes = []
         self._last_present_tags = {}  # id: tags
         self._ignore_tag_selector = False
+        self._height_below_360 = False
 
         # We can select multiple files of multiple types at once, but
         # they're not guaranteed to all have the same available extra tags.
@@ -465,7 +466,9 @@ class EartagMoreTagsGroup(Gtk.Box):
     def refresh_tag_filter(self, *args):
         """Refreshes the filter for the additional tag add row."""
         self.tag_filter.changed(Gtk.FilterChange.DIFFERENT)
-        self.tag_entry_listbox.props.visible = bool(self.get_present_tags())
+        self.tag_entry_listbox.props.visible = bool(
+            [i for i in self.get_rows_sorted().keys() if i in EXTRA_TAGS]
+        )
 
     @Gtk.Template.Callback()
     def add_row_from_selector(self, selector, tag):
@@ -477,7 +480,7 @@ class EartagMoreTagsGroup(Gtk.Box):
         if not self.tag_selector.tag_filter_func(_tag_name):
             return False
 
-        present_tags = self.get_present_tags()
+        present_tags = list(self.get_rows_sorted().keys())
 
         tag_name = _tag_name.get_string()
         tag_prop = self.tag_selector.tag_names_swapped[tag_name]
@@ -728,6 +731,19 @@ class EartagMoreTagsGroup(Gtk.Box):
 
         self.skip_filter_change = False
 
+    @GObject.Property(type=bool, default=False)
+    def height_below_360(self):
+        """Hack to fix https://gitlab.gnome.org/World/eartag/-/merge_requests/130"""
+        return self._height_below_360
+
+    @height_below_360.setter
+    def height_below_360(self, value):
+        self._height_below_360 = value
+        if value is True:
+            self.tag_selector.set_direction(Gtk.ArrowType.UP)
+        else:
+            self.tag_selector.set_direction(Gtk.ArrowType.DOWN)
+
 
 class EartagFileInfoLabel(Gtk.Label):
     """Label showing information about opened files."""
@@ -769,9 +785,7 @@ class EartagFileInfoLabel(Gtk.Label):
         elif channels == 2:
             channels_readable = "Stereo"
         else:
-            channels_readable = gettext.ngettext(
-                "1 channel", "{n} channels", channels
-            ).format(
+            channels_readable = ngettext("1 channel", "{n} channels", channels).format(
                 n=channels
             )  # noqa: E501
 
@@ -1035,3 +1049,12 @@ class EartagFileView(Gtk.Stack):
     @compact.setter
     def compact(self, value):
         self.more_tags_group.compact = value
+
+    @GObject.Property(type=bool, default=False)
+    def height_below_360(self):
+        """Hack to fix https://gitlab.gnome.org/World/eartag/-/merge_requests/130"""
+        return self.more_tags_group.height_below_360
+
+    @height_below_360.setter
+    def height_below_360(self, value):
+        self.more_tags_group.height_below_360 = value
