@@ -53,7 +53,7 @@ def make_request(url, raw=False, _recursion=0):
     headers = {"User-Agent": USER_AGENT}
     try:
         request = urllib.request.Request(url, headers=headers)
-        with urllib.request.urlopen(request) as data_raw:
+        with urllib.request.urlopen(request, timeout=30) as data_raw:
             if raw:
                 data = data_raw.read()
             else:
@@ -532,6 +532,11 @@ class MusicBrainzRelease(GObject.Object):
 
     def update_thumbnail(self):
         """Downloads the thumbnail for the release from coverartarchive.org"""
+        if config.get_enum("musicbrainz-cover-size") == 0:
+            self.cover_tempfiles["thumbnail"] = ""
+            self.notify("thumbnail-path")
+            return
+
         url = f"https://coverartarchive.org/release/{self.release_id}/front-250"
         if url in MusicBrainzRelease.cover_cache:
             self.cover_tempfiles["thumbnail"] = MusicBrainzRelease.cover_cache[url]
@@ -615,7 +620,7 @@ class MusicBrainzRelease(GObject.Object):
     @classmethod
     def clear_tempfiles(cls):
         """Closes all cover tempfiles."""
-        for tmp in cls.cover_cache:
+        for tmp in cls.cover_cache.values():
             try:
                 tmp.close()
             except AttributeError:
@@ -730,6 +735,11 @@ class MusicBrainzReleaseGroup(GObject.Object):
 
     def update_thumbnail(self):
         """Downloads the thumbnail for the release from coverartarchive.org"""
+        if config.get_enum("musicbrainz-cover-size") == 0:
+            self.cover_tempfiles["thumbnail"] = ""
+            self.notify("thumbnail-path")
+            return
+
         url = f"https://coverartarchive.org/release-group/{self.relgroup_id}/front-250"
         if url in MusicBrainzRelease.cover_cache:
             self.cover_tempfiles["thumbnail"] = MusicBrainzRelease.cover_cache[url]
