@@ -101,12 +101,14 @@ class EartagWindow(Adw.ApplicationWindow):
     loading_progressbar_revealer = Gtk.Template.Child()
 
     def __init__(self, application, paths=None, devel=False):
-        super().__init__(application=application, title="Ear Tag")
+        super().__init__(application=application, title=_("Ear Tag"))
         self._undo_all_data = {}
 
         if devel:
             self.add_css_class("devel")
 
+        self.set_icon_name(application.get_application_id())
+
         self.file_chooser = Gtk.FileDialog(modal=True)
         self._cancellable = Gio.Cancellable.new()
 
@@ -146,6 +148,9 @@ class EartagWindow(Adw.ApplicationWindow):
             "revealed",
             GObject.BindingFlags.BIDIRECTIONAL | GObject.BindingFlags.SYNC_CREATE,
         )
+        self.sidebar_file_list.connect(
+            "notify::selection-mode", self.update_selection_mode
+        )
 
         self.connect("close-request", self.on_close_request)
 
@@ -219,6 +224,14 @@ class EartagWindow(Adw.ApplicationWindow):
 
         # Set up the active view (hide fileview if there are no selected files)
         selected_files_count = self.file_manager.get_n_selected()
+
+        if selected_files_count == self.file_manager.get_n_files():
+            self.select_all_button.set_icon_name("edit-select-none-symbolic")
+            self.select_all_button.set_tooltip_text(_("Unselect all files"))
+        else:
+            self.select_all_button.set_icon_name("edit-select-all-symbolic")
+            self.select_all_button.set_tooltip_text(_("Select all files"))
+
         if selected_files_count <= 0:
             try:
                 for action in (
@@ -232,7 +245,7 @@ class EartagWindow(Adw.ApplicationWindow):
                     action.set_enabled(False)
             except AttributeError:
                 return
-            self.set_title("Ear Tag")
+            self.set_title(_("Ear Tag"))
             self.window_title.set_subtitle("")
             if self.file_manager.files:
                 self.file_view.content_stack.set_visible_child(
@@ -247,16 +260,17 @@ class EartagWindow(Adw.ApplicationWindow):
         self.file_view.content_stack.set_visible_child(self.file_view.content_scroll)
 
         # Set up window title and file info label
+        _title = _("Ear Tag")
         if len(files) == 1:
             file = files[0]
             file_basename = os.path.basename(file.path)
-            self.set_title("{f} — Ear Tag".format(f=file_basename))
+            self.set_title("{f} — {title}".format(f=file_basename, title=_title))
             self.window_title.set_subtitle(file_basename)
         else:
             # TRANSLATORS: Placeholder for file path when multiple files are selected.
             # Shows up in the titlebar of the application.
             _multiple_files = _("(Multiple files selected)")
-            self.set_title("{f} — Ear Tag".format(f=_multiple_files))
+            self.set_title("{f} — {title}".format(f=_multiple_files, title=_title))
             self.window_title.set_subtitle(_multiple_files)
 
         is_modified = False
@@ -569,7 +583,7 @@ class EartagWindow(Adw.ApplicationWindow):
             else:
                 # TRANSLATORS: {n} is a placeholder for the amount of files.
                 # **Do not change the letter between the curly brackets!**
-                selected_message = gettext.ngettext(
+                selected_message = ngettext(
                     "1 file selected", "{n} files selected", selected_file_count
                 ).format(n=selected_file_count)
                 self.remove_selected_button.set_sensitive(True)
@@ -587,6 +601,11 @@ class EartagWindow(Adw.ApplicationWindow):
         # Workaround for the text not showing up on initial load
         self.refresh_actionbar_button_state()
 
+    def update_selection_mode(self, filelist, *args):
+        self.notify("selection-mode")
+        # Workaround for the text not showing up on initial load
+        self.refresh_actionbar_button_state()
+
     def select_next(self, *args):
         """Selects the next item on the sidebar."""
         return self.file_manager.select_next()
@@ -650,7 +669,7 @@ class EartagWindow(Adw.ApplicationWindow):
         toast = Adw.Toast.new(
             # TRANSLATORS: {n} is a placeholder for the amount of files.
             # **Do not change the letter between the curly brackets!**
-            gettext.ngettext(
+            ngettext(
                 "Undid changes in 1 file",
                 "Undid changes in {n} files",
                 self._undo_all_count,
@@ -686,7 +705,7 @@ class EartagWindow(Adw.ApplicationWindow):
         toast = Adw.Toast.new(
             # TRANSLATORS: {n} is a placeholder for the amount of files.
             # **Do not change the letter between the curly brackets!**
-            gettext.ngettext(
+            ngettext(
                 "Redid changes in 1 file",
                 "Redid changes in {n} files",
                 self._redo_all_count,
@@ -734,7 +753,7 @@ class EartagWindow(Adw.ApplicationWindow):
             # TRANSLATORS: {n} is a placeholder for the amount of files
             # that tags have been removed from.
             # **Do not change the letter between the curly brackets!**
-            gettext.ngettext(
+            ngettext(
                 "Removed tags from 1 file",
                 "Removed tags from {n} files",
                 self._delete_all_tags_count,
@@ -769,7 +788,7 @@ class EartagWindow(Adw.ApplicationWindow):
         toast = Adw.Toast.new(
             # TRANSLATORS: {n} is a placeholder for the amount of files.
             # **Do not change the letter between the curly brackets!**
-            gettext.ngettext(
+            ngettext(
                 "Undid tag removal in 1 file",
                 "Undid tag removal in {n} files",
                 self._undo_delete_all_count,
