@@ -143,14 +143,14 @@ def backend_read(file, skip_channels=False):
                 file.get_property("front_cover_path"),
                 os.path.join(EXAMPLES_DIR, "cover.png"),
                 shallow=False,
-            ), "cover art not found in file"  # noqa: E501
+            ), "cover art differs from test value"  # noqa: E501
 
             assert file.get_property("back_cover_path"), "back cover not found in file"
             assert filecmp.cmp(
                 file.get_property("back_cover_path"),
                 os.path.join(EXAMPLES_DIR, "cover_back.png"),
                 shallow=False,
-            ), "back cover not found in file"  # noqa: E501
+            ), "back cover differs from test value"  # noqa: E501
         except TypeError:
             raise ValueError("cover art not found in file")
 
@@ -194,13 +194,18 @@ def backend_write(file, skip_channels=False):
         assert file.has_tag(prop), f"tag {prop} not found in file"
 
     if file._supports_album_covers:
-        file.set_property("front_cover_path", os.path.join(EXAMPLES_DIR, "cover.png"))
-        assert file.get_property("front_cover_path")
+        for cover_filetype in ("jpg", "jp2", "bmp", "webp", "png"):
+            file.set_property(
+                "front_cover_path",
+                os.path.join(EXAMPLES_DIR, f"cover.{cover_filetype}"),
+            )
+            assert file.get_property("front_cover_path")
 
-        file.set_property(
-            "back_cover_path", os.path.join(EXAMPLES_DIR, "cover_back.png")
-        )
-        assert file.get_property("back_cover_path")
+            file.set_property(
+                "back_cover_path",
+                os.path.join(EXAMPLES_DIR, f"cover_back.{cover_filetype}"),
+            )
+            assert file.get_property("back_cover_path")
 
     assert file.get_property("is_modified") is True
     props_set = set(tuple(file.handled_properties) + tuple(file.supported_extra_tags))
@@ -277,9 +282,10 @@ def backend_write_empty(file, skip_channels=False):
         file.set_property("totaltracknumber", 1)
         assert file.has_tag("tracknumber")
         file.set_property("tracknumber", 0)
-        assert file.has_tag("tracknumber")
+        assert file.has_tag("totaltracknumber")
         file.set_property("totaltracknumber", 0)
         assert not file.has_tag("tracknumber")
+        assert not file.has_tag("totaltracknumber")
 
         file.set_property("tracknumber", 1)
         file.set_property("totaltracknumber", 1)
